@@ -386,7 +386,7 @@ class CoreArgumentParser(ArgumentParser):
         exec_parser.add_argument('--learn', action='store_true', dest='learn', default=False,
                                  help='matches are not downloaded but will be skipped in the future')
         exec_parser.add_argument('--cron', action=CronAction, default=False, nargs=0,
-                                 help='use when scheduling FlexGet with cron or other scheduler: allows background '
+                                 help='use when executing FlexGet non-interactively: allows background '
                                       'maintenance to run, disables stdout and stderr output, reduces logging level')
         exec_parser.add_argument('--profile', action='store_true', default=False, help=SUPPRESS)
         exec_parser.add_argument('--disable-phases', nargs='*', help=SUPPRESS)
