@@ -11,9 +11,8 @@ from sqlalchemy.schema import ForeignKey, Index
 from sqlalchemy.orm import relation
 
 from flexget import db_schema
-from flexget.plugin import internet, PluginError
+from flexget.plugin import internet, PluginError, get_plugin_by_name
 from flexget.utils import requests
-from flexget.utils.titles import MovieParser
 from flexget.utils.database import text_date_synonym, with_session
 from flexget.utils.sqlalchemy_utils import table_schema, table_add_column
 
@@ -259,8 +258,7 @@ def lookup_movie(title=None, year=None, rottentomatoes_id=None, smart_match=None
 
     if smart_match:
         # If smart_match was specified, and we don't have more specific criteria, parse it into a title and year
-        title_parser = MovieParser()
-        title_parser.parse(smart_match)
+        title_parser = get_plugin_by_name('parsing').instance.parse_movie(smart_match)
         title = title_parser.name
         year = title_parser.year
         if title == '' and not (rottentomatoes_id or title):
