@@ -1,8 +1,8 @@
 from __future__ import unicode_literals, division, absolute_import
 import logging
 
-from flexget import validator
-from flexget.plugin import register_plugin
+from flexget import plugin
+from flexget.event import event
 
 log = logging.getLogger('metainfo_task')
 
@@ -12,8 +12,7 @@ class MetainfoTask(object):
     Set 'task' field for entries.
     """
 
-    def validator(self):
-        return validator.factory('boolean')
+    schema = {'type': 'boolean'}
 
     def on_task_metainfo(self, task, config):
         # check if explicitly disabled (value set to false)
@@ -24,4 +23,6 @@ class MetainfoTask(object):
             entry['task'] = task.name
 
 
-register_plugin(MetainfoTask, 'metainfo_task', api_ver=2, builtin=True)
+@event('plugin.register')
+def register_plugin():
+    plugin.register(MetainfoTask, 'metainfo_task', api_ver=2, builtin=True)
