@@ -1,7 +1,9 @@
 from __future__ import unicode_literals, division, absolute_import
 import logging
 import time
-from flexget.plugin import register_plugin, priority
+
+from flexget import plugin
+from flexget.event import event
 
 log = logging.getLogger('sleep')
 
@@ -13,10 +15,13 @@ class PluginSleep(object):
         from flexget import validator
         return validator.factory('number')
 
-    @priority(255)
+    @plugin.priority(255)
     def on_task_start(self, task, config):
         if config:
             log.verbose('Sleeping for %d seconds.' % config)
             time.sleep(config)
 
-register_plugin(PluginSleep, 'sleep', api_ver=2)
+
+@event('plugin.register')
+def register_plugin():
+    plugin.register(PluginSleep, 'sleep', api_ver=2)
