@@ -9,6 +9,7 @@ from requests.exceptions import RequestException
 from flexget import plugin, validator
 from flexget.event import event
 from flexget.utils import json, requests
+from flexget.config_schema import one_or_more
 
 log = getLogger('pyload')
 
@@ -55,24 +56,29 @@ class PluginPyLoad(object):
     DEFAULT_PREFERRED_HOSTER_ONLY = False
     DEFAULT_HANDLE_NO_URL_AS_FAILURE = False
 
-    def validator(self):
-        """Return config validator"""
-        root = validator.factory()
-        root.accept('boolean')
-        advanced = root.accept('dict')
-        advanced.accept('text', key='api')
-        advanced.accept('text', key='username')
-        advanced.accept('text', key='password')
-        advanced.accept('text', key='folder')
-        advanced.accept('text', key='package')
-        advanced.accept('boolean', key='queue')
-        advanced.accept('boolean', key='parse_url')
-        advanced.accept('boolean', key='multiple_hoster')
-        advanced.accept('list', key='hoster').accept('text')
-        advanced.accept('boolean', key='preferred_hoster_only')
-        advanced.accept('boolean', key='handle_no_url_as_failure')
-        advanced.accept('boolean', key='enabled')
-        return root
+    schema = {
+        'oneOf': [
+            {'type': 'boolean'},
+            {'type': 'object',
+                'properties': {
+                    'api': {'type': 'string'},
+                    'username': {'type': 'string'},
+                    'password': {'type': 'string'},
+                    'folder': {'type': 'string'},
+                    'package': {'type': 'string'},
+                    'queue': {'type': 'boolean'},
+                    'parse_url': {'type': 'boolean'},
+                    'multiple_hoster': {'type': 'boolean'},
+                    'hoster': one_or_more({'type': 'string'}),
+                    'preferred_hoster_only': {'type': 'boolean'},
+                    'handle_no_url_as_failure': {'type': 'boolean'},
+                    'enabled': {'type': 'boolean'},
+
+                },
+                'additionalProperties': False
+             }
+        ]
+    }
 
 
     def on_task_output(self, task, config):
