@@ -28,19 +28,21 @@ class OutputSabnzbd(object):
         pp: ...
         priority: ...
     """
-
-    def validator(self):
-        from flexget import validator
-        config = validator.factory('dict')
-        config.accept('text', key='key', required=True)
-        config.accept('url', key='url', required=True)
-        config.accept('text', key='category')
-        config.accept('text', key='script')
-        config.accept('text', key='pp')
-        config.accept('integer', key='priority')
-        config.accept('text', key='password')
-        config.accept('text', key='username')
-        return config
+    schema = {
+        'type': 'object',
+        'properties': {
+            'key': {'type': 'string'},
+            'url': {'type': 'string', 'format': 'url'},
+            'category': {'type': 'string'},
+            'script': {'type': 'string'},
+            'pp': {'type': 'string'},
+            'priority': {'type': 'integer'},
+            'password': {'type': 'string'},
+            'username': {'type': 'string'},
+        },
+        'required': ['key', 'url'],
+        'additionalProperties': False,
+    }
 
     def get_params(self, config):
         params = {}
