@@ -3,8 +3,10 @@ import logging
 import os
 import yaml
 
-from flexget.plugin import priority, register_plugin, PluginError
-from flexget.config_schema import one_or_more
+from flexget import plugin
+from flexget.config_schema import one_or_more, process_config
+from flexget.event import event
+from flexget.utils.tools import MergeException, merge_dict_from_to
 
 log = logging.getLogger('include')
 
@@ -20,11 +22,10 @@ class PluginInclude(object):
     File content must be valid for a task configuration
     """
 
-    # TODO: validate files exist, but relative paths should be relative to config dir
     schema = one_or_more({'type': 'string'})
 
-    @priority(254)
-    def on_process_start(self, task, config):
+    @plugin.priority(254)
+    def on_task_start(self, task, config):
         if not config:
             return
 
@@ -37,14 +38,19 @@ class PluginInclude(object):
             if not os.path.isabs(name):
                 name = os.path.join(task.manager.config_base, name)
             include = yaml.load(file(name))
-            if not isinstance(include, dict):
-                raise PluginError('Include file format is invalid: %s' % name)
+            errors = process_config(include, plugin.plugin_schemas(context='task'))
+            if errors:
+                log.error('Included file %s has invalid config:' % name)
+                for error in errors:
+                    log.error('[%s] %s', error.json_pointer, error.message)
+                task.abort('Invalid config in included file %s' % name)
             log.debug('Merging %s into task %s' % (name, task.name))
             # merge
-            from flexget.utils.tools import MergeException, merge_dict_from_to
             try:
                 merge_dict_from_to(include, task.config)
             except MergeException:
-                raise PluginError('Failed to merge include file to task %s, incompatible datatypes' % (task.name))
+                raise plugin.PluginError('Failed to merge include file to task %s, incompatible datatypes' % task.name)
 
-register_plugin(PluginInclude, 'include', api_ver=2, builtin=True)
+@event('plugin.register')
+def register_plugin():
+    plugin.register(PluginInclude, 'include', api_ver=2, builtin=True)
