@@ -14,7 +14,7 @@ from flexget.utils.search import torrent_availability, normalize_unicode
 log = logging.getLogger('piratebay')
 
 CUR_TLD = "se"
-TLDS = "com|org|sx|se|ac|pe|gy|%s" % CUR_TLD
+TLDS = "com|org|sx|ac|pe|gy|%s" % CUR_TLD
 
 URL_MATCH = re.compile("^http://(?:torrents\.)?thepiratebay\.(?:%s)/.*$" % TLDS)
 URL_SEARCH = re.compile("^http://thepiratebay\.(?:%s)/search/.*$" % TLDS)
