@@ -21,8 +21,7 @@ def table_exists(name, session):
     :rtype: bool
     """
     try:
-        meta = MetaData(bind=session.connection())
-        Table(name, meta, autoload=True, autoload_with=session.connection())
+        table_schema(name, session)
     except NoSuchTableError:
         return False
     return True
@@ -33,10 +32,7 @@ def table_schema(name, session):
     :returns: Table schema using SQLAlchemy reflect as it currently exists in the db
     :rtype: Table
     """
-    meta = MetaData(bind=session.bind, reflect=True)
-    for table in meta.sorted_tables:
-        if table.name == name:
-            return table
+    return Table(name, MetaData(bind=session.bind), autoload=True)
 
 
 def table_columns(table, session):
@@ -91,7 +87,8 @@ def table_add_column(table, name, col_type, session, default=None):
 
 def drop_tables(names, session):
     """Takes a list of table names and drops them from the database if they exist."""
-    metadata = MetaData(bind=session.bind, reflect=True)
+    metadata = MetaData()
+    metadata.reflect(bind=session.bind)
     for table in metadata.sorted_tables:
         if table.name in names:
             table.drop()
