@@ -427,3 +427,13 @@ class BufferQueue(Queue.Queue):
 
     def write(self, line):
         self.put(line)
+
+
+def singleton(cls):
+    instances = {}
+
+    def getinstance(*args, **kwargs):
+        if cls not in instances:
+            instances[cls] = cls(*args, **kwargs)
+        return instances[cls]
+    return getinstance
