@@ -1,8 +1,10 @@
-from __future__ import unicode_literals, division, absolute_import, print_function
+from __future__ import absolute_import, division, print_function, unicode_literals
+
 import re
 
 from flexget.config_schema import process_config
 
+
 # TODO: rename all validator.valid -> validator.accepts / accepted / accept ?
 
 
