@@ -1,10 +1,15 @@
 from __future__ import unicode_literals, division, absolute_import
+
+from flexget import plugin
 from flexget.entry import Entry
-from flexget.plugin import register_plugin
+from flexget.event import event
 
 
 class ExternalPlugin(object):
     def on_task_input(self, task, config):
         return [Entry('test entry', 'fake url')]
 
-register_plugin(ExternalPlugin, 'external_plugin', api_ver=2)
+
+@event('plugin.register')
+def register_plugin():
+    plugin.register(ExternalPlugin, 'external_plugin', api_ver=2)
